Binomial Distribution and Gaussian Distribution Package

This is a python package which is able to read data from a text file and output calculates and visualize the binomial or the gaussian distributions. The package has capability to calculate and visualize the probability density function for both the binomial and gaussian distributions.

Dependencies

OS System - OS Independent
API- Atom, Jupyter Notebook, or any source code editor equipped with Python
Programming language - Python >= 3

Download from:
https://pypi.org/simple/distributions/gauss_bin_prob


After downloading the package follow the command below to execute the program
pip install gauss_bin_prob

Author
 github.com/Wakhie

Version 
0.1

Acknowledgments
udacity, Andrew Paster - (AI & ML Foundation) course instructor